@@ -99,6 +99,10 @@ class ShowMember(command.ShowOne):
             data = self.app.client_manager.load_balancer.member_show(
                 pool_id=pool_id, member_id=member_id)
 
+        # Handle older API versions that did not have the vnic_type
+        if not data.get('vnic_type', False):
+            data['vnic_type'] = 'normal'
+
         formatters = {'tags': v2_utils.format_list_flat}
 
         return (rows, (utils.get_dict_properties(
@@ -126,13 +130,13 @@ class CreateMember(command.ShowOne):
             '--disable-backup',
             action='store_true',
             default=None,
-            help="Disable member backup (default)"
+            help="Disable member backup (default)."
         )
         backup.add_argument(
             '--enable-backup',
             action='store_true',
             default=None,
-            help="Enable member backup"
+            help="Enable member backup."
         )
         parser.add_argument(
             '--weight',
@@ -145,7 +149,7 @@ class CreateMember(command.ShowOne):
         parser.add_argument(
             '--address',
             metavar='<ip_address>',
-            help="The IP address of the backend member server",
+            help="The IP address of the backend member server.",
             required=True
         )
         parser.add_argument(
@@ -179,18 +183,24 @@ class CreateMember(command.ShowOne):
             '--enable',
             action='store_true',
             default=None,
-            help="Enable member (default)"
+            help="Enable member (default)."
         )
         admin_group.add_argument(
             '--disable',
             action='store_true',
             default=None,
-            help="Disable member"
+            help="Disable member."
         )
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
+        )
+        parser.add_argument(
+            '--request-sriov',
+            action='store_true',
+            default=None,
+            help='Request that the member port be created using an SR-IOV VF.',
         )
 
         _tag.add_tag_option_to_parser_for_create(
@@ -225,6 +235,10 @@ class CreateMember(command.ShowOne):
                         pool_id, data['member']['id']))
             }
 
+        # Handle older API versions that did not have the vnic_type
+        if not data['member'].get('vnic_type', False):
+            data['member']['vnic_type'] = 'normal'
+
         formatters = {'tags': v2_utils.format_list_flat}
 
         return (rows,
@@ -246,38 +260,38 @@ class SetMember(command.Command):
         parser.add_argument(
             'member',
             metavar='<member>',
-            help="Name or ID of the member to update"
+            help="Name or ID of the member to update."
         )
         parser.add_argument(
             '--name',
             metavar='<name>',
-            help="Set the name of the member"
+            help="Set the name of the member."
         )
         backup = parser.add_mutually_exclusive_group()
         backup.add_argument(
             '--disable-backup',
             action='store_true',
             default=None,
-            help="Disable member backup (default)"
+            help="Disable member backup (default)."
         )
         backup.add_argument(
             '--enable-backup',
             action='store_true',
             default=None,
-            help="Enable member backup"
+            help="Enable member backup."
         )
         parser.add_argument(
             '--weight',
             metavar='<weight>',
             type=int,
-            help="Set the weight of member in the pool"
+            help="Set the weight of member in the pool."
         )
         parser.add_argument(
             '--monitor-port',
             metavar='<monitor_port>',
             type=int,
             help="An alternate protocol port used for health monitoring a "
-                 "backend member",
+                 "backend member.",
         )
         parser.add_argument(
             '--monitor-address',
@@ -290,17 +304,17 @@ class SetMember(command.Command):
             '--enable',
             action='store_true',
             default=None,
-            help="Set the admin_state_up to True"
+            help="Set the admin_state_up to True."
         )
         admin_group.add_argument(
             '--disable',
             action='store_true',
             default=None,
-            help="Set the admin_state_up to False")
+            help="Set the admin_state_up to False.")
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         _tag.add_tag_option_to_parser_for_set(parser, 'member')
@@ -357,7 +371,7 @@ class DeleteMember(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
 
         return parser
@@ -427,7 +441,7 @@ class UnsetMember(command.Command):
         parser.add_argument(
             '--wait',
             action='store_true',
-            help='Wait for action to complete',
+            help='Wait for action to complete.',
         )
         _tag.add_tag_option_to_parser_for_unset(parser, 'member')
 
